@@ -3,10 +3,10 @@ package App::ThisDist;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-02'; # DATE
 our $DIST = 'App-ThisDist'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
-# ABSTRACT: This CPAN {distribution,module,author,...}
+# ABSTRACT: Print Perl {distribution,module,author,...} associated with current directory
 
 __END__
 
@@ -16,11 +16,11 @@ __END__
 
 =head1 NAME
 
-App::ThisDist - This CPAN {distribution,module,author,...}
+App::ThisDist - Print Perl {distribution,module,author,...} associated with current directory
 
 =head1 VERSION
 
-This document describes version 0.002 of App::ThisDist (from Perl distribution App-ThisDist), released on 2020-10-02.
+This document describes version 0.003 of App::ThisDist (from Perl distribution App-ThisDist), released on 2020-10-02.
 
 =head1 HOMEPAGE
 
